PACK PS4 500 Go + GTA V - PS4
Description: PACK PS4 500 Go + GTA V, Micromania, numéro un français du jeu vidéo. Retrouvez les tests de tous les jeux, réservez et achetez les dernières nouveautés consoles, jeux vidéo et PC
Keywords: micromania

Menu
Micromania

- - Nos magasins
  - Nos services
  - Nos dossiers
  - Web TV
- Search site:
- Mon compte
- Panier 0

## Plus de vues

# Pack PS4 500 Go + Grand Theft Auto V

PS4

SKU# 58763

## Description :

Pour Noël, s'offrir une PS4, c'est bien. Se l'offrir avec GTA V, c'est mieux !

Description complète En images En vidéos

#### Vendu neuf par
Micromania

Promotion

439,99 €

399,99 €

-10%

(*) Prix internet

- Fabricant : Sony
- Couleur : Noir
- Capacité disque dur : 500 Go
- Connection ethernet : Oui
- Wi-Fi : oui
- Nombre de ports USB : 2
- Date de sortie : 18 nov. 2014

18Age minimum conseillé
par Micromania

- Fabricant : Sony
- Couleur : Noir
- Capacité disque dur : 500 Go
- Connection ethernet : Oui
- Wi-Fi : oui
- Nombre de ports USB : 2
- Date de sortie : 18 nov. 2014

#### Retrait 1h en magasin

Ce produit est disponible dans 209 magasins Micromania
Vérifier la disponibilité

- Fabricant : Sony
- Couleur : Noir
- Capacité disque dur : 500 Go
- Connection ethernet : Oui
- Wi-Fi : oui
- Nombre de ports USB : 2
- Date de sortie : 18 nov. 2014

18Age minimum conseillé
par Micromania

#### Retrait 1h en magasin

Ce produit est disponible dans 209 magasins Micromania
Vérifier la disponibilité

#### Plus d'informations

En vidéos
En images

- 1/12
- 2/12
- 3/12
- 4/12
- 5/12
- 6/12
- 7/12
- 8/12
- 9/12
- 10/12
- 11/12
- 12/12

Description

Contenu du pack :

- Le jeu GTA V
- Une PlayStation 4
- Une manette DUALSHOCK 4
- Un câble HDMI
- Un câble USB
- Alimentation
- Casque audio mono
La console
- Disque dur 500 Go
- Lecteur Blu-ray (DVD)
- Poids : 2,8 Kg
- Dimension : 275×53×305 mm
- 2 ports USB 3.0
- Port HDMI
- Ethernet, Wi-Fi, Bluetooth, Digital Out (optique), Auxiliaire (x1)
Centré sur les joueurs, inspiré par les développeurs
Le système PS4 a été conçu pour offrir aux joueurs PlayStation les meilleurs jeux et les expériences les plus immersives. Spécialement pensé pour répondre à leurs besoins, la PS4 permet aussi aux plus grands développeurs de jeux du monde de laisser libre cours à leur créativité.
La PS4 connecte également le joueur de manière fluide au vaste monde dexpériences de PlayStation à travers le système et les espaces mobiles, ainsi que PlayStation Network (PSN).
Larchitecture du système PS4 se distingue par ses hautes performances et sa facilité de développement. Elle repose sur une puissante puce modifiée à huit curs x86-64 et un processeur graphique de pointe.
La PS4 est doté de 8 Go de mémoire système unifiée facilitant la création de jeux et augmentant la richesse de contenu possible sur la plateforme. La mémoire est de type GDDR5. Elle offre au système une bande passante de 176 Go/seconde et accroît encore sa performance graphique.
Pour les joueurs, le tout se traduit par des graphismes haute-fidélité détaillés et une expérience de jeu immersive au-delà de toute espérance.
Expériences de jeu partagées
- Les interactions sociales sont au cur des expériences PS4.
- Doté dun système de compression et décompression vidéo dédié permanent qui permet de télécharger instantanément des vidéos de jeu.
- Les joueurs peuvent partager leurs victoires épiques dun simple geste. Il suffit dappuyer sur la touche « SHARE » (partager) de la manette, scanner les dernières minutes de jeu, les annoter et reprendre la partie.
- Les joueurs peuvent lier leur compte Facebook à leur compte Sony Entertainment Network. Les utilisateurs peuvent développer leurs connexions en jouant en coopération ou en dialoguant via lespace de discussion Cross-game.
Écrans secondaires PS4
- Prise en charge des écrans secondaires, comme le système PS Vita, les smartphones et les tablettes, pour permettre aux joueurs demporter leurs contenus favoris où quils aillent. Les joueurs peuvent ainsi porter leurs jeux PS4 sur leur PS Vita.
- Une nouvelle application de SCE appelée « PlayStation App » permettra aux appareils iPhone, iPad, smartphones et tablettes AndroidTM de devenir des écrans secondaires.
Jeu immédiat
- La PS4 réduit considérablement la latence séparant les joueurs de leurs contenus. Elle intègre une fonctionnalité de « suspend mode » (suspens) qui la maintient en état de veille tout en préservant la session de jeu. Le temps aujourdhui nécessaire pour démarrer le système et charger une partie sauvegardée appartiendra bientôt au passé. Le joueur appuie sur la touche dalimentation et retrouve instantanément sa partie là où il lavait quittée. De plus, lutilisateur peut lancer plusieurs applications, dont un navigateur internet, alors quil joue à un jeu sur PS4.
Le système PS4 permet également de télécharger ou de mettre à jour des jeux en tâche de fond ou en veille. Il va même encore plus loin en offrant la possibilité de jouer à un jeu numérique alors quil est en cours de téléchargement.
Du contenu ciblé et personnalisé
- Grâce aux nouveaux menus, le joueur peut parcourir les informations liées aux jeux partagées par ses amis, regarder simplement ses amis jouer ou obtenir des informations sur du contenu recommandé (jeux, émissions de télévision, films).

A propos de GTA V:

Retrouvez Franklin, Michael et Trevor, les trois héros de GTA V, dans une version du jeu remaniée. Grâce à la puissance de la PS4, le jeu est maintenant en Full HD et permet de s'immerger dans l'univers de Los Santos comme jamais.

#### Les accessoires PS4

- PS4

  ## Présentoir vertical blanc

  19,99 €
- PS4

  ## Casque Ear Force P12

  59,99 €
- PS4

  ## Enceinte Eternity Bluetooth

  34,99 €
- PS4

  ## Manette Dualshock 4 Rouge

  59,99 €

#### Les meilleures ventes PS4

- PS4

  ## PlayStation 4 (PS4)

  399,99 €
- Promotion
  PS4

  ## Call of Duty : Advanced Warfare - Exclusivité Micromania

  69,99 €

  49,99 €

  -29%